==> react-head-1.7.0.tgz: package/lib/utils.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import * as React from 'react';
import { Children as ReactChildren } from 'react';
/**
 * Extract value in a specific order
 */
var extractKeyFromTag = function (tag) {
    var _a, _b;
    var name = tag.name, hreflang = tag.hreflang, rel = tag.rel, content = tag.content;
    return (_b = (_a = name !== null && name !== void 0 ? name : hreflang) !== null && _a !== void 0 ? _a : rel) !== null && _b !== void 0 ? _b : content;
};
/**
 * Extract children from React by tag type and return an array of React Type Component
 */
export var extract = function (_a) {
    var children = _a.children, byTag = _a.byTag;
    var arrayOfComponents = ReactChildren.toArray(children);
    return arrayOfComponents.filter(function (child) {
        return React.isValidElement(child) && child.type === byTag;
    }).map(function (child) {
        var el = child;
        return __assign({}, el.props);
    });
};
export var renderTags = function (_a) {
    var _b = _a.tagsArray, tagsArray = _b === void 0 ? [] : _b, Component = _a.Component;
    return tagsArray.map(function (tag) {
        var hrefLang = tag.hreflang, restOfTagInfo = __rest(tag, ["hreflang"]);
        return (_jsx(Component, __assign({ hrefLang: hrefLang }, restOfTagInfo), extractKeyFromTag(tag)));
    });
};
export var extractTagsFrom = function (_a) {
    var children = _a.children, tag = _a.tag, fallback = _a.fallback;
    if (children != null) {
        return extract({ children: children, byTag: tag });
    }
    return fallback;
};
export var extractTitleFrom = function (_a) {
    var children = _a.children, _b = _a.fallback, fallback = _b === void 0 ? '' : _b;
    if (typeof children === 'undefined')
        return fallback;
    var listOfTitles = extract({ children: children, byTag: 'title' });
    if (listOfTitles.length > 0) {
        var title = listOfTitles[0];
        return title.children !== undefined ? title.children : fallback;
    }
    return fallback;
};

==> react-head-1.10.0.tgz: package/lib/utils.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import * as React from 'react';
import { Children as ReactChildren } from 'react';
var checkRelNeedsHref = function (rel) {
    return ['alternate', 'preload', 'prefetch'].includes(rel);
};
/**
 * Use rel as key but put extra info if needed
 * to avoid duplicated keys
 */
var extractRelAsKey = function (tag) {
    var rel = tag.rel, href = tag.href, hreflang = tag.hreflang;
    if (rel != null) {
        if (hreflang != null)
            return rel + "-" + hreflang;
        if (checkRelNeedsHref(rel) && href != null)
            return rel + "-" + href;
        return rel;
    }
};
/**
 * Extract value in a specific order
 */
var extractKeyFromTag = function (tag) {
    var _a;
    var name = tag.name, content = tag.content;
    return (_a = name !== null && name !== void 0 ? name : extractRelAsKey(tag)) !== null && _a !== void 0 ? _a : content;
};
/**
 * Extract children from React by tag type and return an array of React Type Component
 */
export var extract = function (_a) {
    var children = _a.children, byTag = _a.byTag;
    var arrayOfComponents = ReactChildren.toArray(children);
    return arrayOfComponents.filter(function (child) {
        return React.isValidElement(child) && child.type === byTag;
    }).map(function (child) {
        var el = child;
        return __assign({}, el.props);
    });
};
export var renderTags = function (_a) {
    var _b = _a.tagsArray, tagsArray = _b === void 0 ? [] : _b, Component = _a.Component;
    return tagsArray.map(function (tag) {
        var hrefLang = tag.hreflang, restOfTagInfo = __rest(tag, ["hreflang"]);
        return (_jsx(Component, __assign({ hrefLang: hrefLang }, restOfTagInfo), extractKeyFromTag(tag)));
    });
};
export var extractTagsFrom = function (_a) {
    var children = _a.children, tag = _a.tag, fallback = _a.fallback;
    if (children != null) {
        return extract({ children: children, byTag: tag });
    }
    return fallback;
};
export var extractTitleFrom = function (_a) {
    var children = _a.children, _b = _a.fallback, fallback = _b === void 0 ? '' : _b;
    if (typeof children === 'undefined')
        return fallback;
    var listOfTitles = extract({ children: children, byTag: 'title' });
    if (listOfTitles.length > 0) {
        var title = listOfTitles[0];
        return title.children !== undefined ? title.children : fallback;
    }
    return fallback;
};
